@@ -57,14 +57,14 @@ let intern_typ i =
          UNKOWNTYPE i
 
 let substring ch l =
- let s = String.create l in
+ let s = Bytes.create l in
  really_input ch s 0 l;
  s
 
 let int ch =
   let s = substring ch 4 in
-  Char.code s.[0] lsl 24 + Char.code s.[1] lsl 16 +
-  Char.code s.[2] lsl 8 + Char.code s.[3]
+  Char.code (Bytes.get s 0) lsl 24 + Char.code (Bytes.get s 1) lsl 16 +
+  Char.code (Bytes.get s 2) lsl 8 + Char.code (Bytes.get s 3)
 
 let sstring store pos =
   let len = ref 0 in
@@ -319,14 +319,14 @@ exception Skip
 let check_entry tag typ tag' typ' =
   if tag <> tag' then begin
     let b = Buffer.create 80 in
-    Format.bprintf b "Expected tag %a but actual tag is %a@?"
+    Util.bprintf b "Expected tag %a but actual tag is %a@?"
       pr_tag tag pr_tag tag';
     Util.print_warning (Buffer.contents b);
     raise Skip
   end;
   if typ <> typ' then begin
     let b = Buffer.create 80 in
-    Format.bprintf b "Entry %a has expected type %a but actual typ is %a@?"
+    Util.bprintf b "Entry %a has expected type %a but actual typ is %a@?"
       pr_tag tag pr_typ typ pr_typ typ';
     Util.fail (Buffer.contents b)
   end
@@ -336,7 +336,7 @@ let estring store entry i tag =
   check_entry tag STRING tag' typ;
   if count <> 1 then begin
     let b = Buffer.create 80 in
-    Format.bprintf b "Entry %a has type STRING with count %d > 1@?"
+    Util.bprintf b "Entry %a has type STRING with count %d > 1@?"
       pr_tag tag count;
     Util.fail (Buffer.contents b)
   end;
@@ -352,7 +352,7 @@ let eint32 store entry i tag =
   check_entry tag INT32 tag' typ;
   if count <> 1 then begin
     let b = Buffer.create 80 in
-    Format.bprintf b "Expecting a single INT32 for entry %a but got %d@?"
+    Util.bprintf b "Expecting a single INT32 for entry %a but got %d@?"
       pr_tag tag count;
     Util.fail (Buffer.contents b)
   end;
@@ -536,7 +536,7 @@ let parse_version s =
       match release with Some r -> check_version r | _ -> false
     then begin
       let b = Buffer.create 80 in
-      Format.bprintf b
+      Util.bprintf b
         "version '%a' not ending with an alphanumeric character@?"
         pr_version (epoch, version, release, distepoch);
       Util.print_warning (Buffer.contents b)
@@ -713,7 +713,8 @@ let dump_fields = ref false
 
 let parse_header pool ignored_packages ch =
   let h = substring ch 8 in
-  if not (h.[0] = '\142' && h.[1] = '\173' && h.[2] = '\232') then
+  let get = Bytes.get in
+  if not (get h 0 = '\142' && get h 1 = '\173' && get h 2 = '\232') then
     Util.fail "Bad header";
   let entry_count = int ch in
   let sz = int ch in
@@ -729,6 +730,7 @@ let parse_header pool ignored_packages ch =
   done;
   Array.sort (fun (tag1, _, _, _) (tag2, _, _, _) -> compare tag1 tag2) entry;
   let store = substring ch sz in
+  let store = Bytes.to_string store in
   try
     let i = move_to entry 0 _NAME in
     let name = estring store entry i _NAME in
